@@ -27,19 +27,6 @@ has 'atoms' => (
     lazy => 1,
 );
 
-#sub tmax {
-    # not the best implementation! what about atoms without coords?
-    # comparing first and last?  really?!  
-    # use coords to calculate tmax,which may be annoying if just interested in charges
-#    my $self = shift;
-#    return (0) unless $self->count_atoms;
-  
-#    my $t0   = $self->get_atoms(0)->count_coords;
-#    my $tn   = $self->get_atoms($self->count_atoms - 1)->count_coords;
-#    croak "first and last atoms no tmax" unless($t0 == $tn);
-#    return ($t0-1);
-#}
-
 sub dipole {
     my $self = shift;
     return ( V(0) ) unless ( $self->count_atoms );
@@ -352,7 +339,7 @@ HackaMol::AtomGroupRole - Role for a group of atoms
 
 =head1 VERSION
 
-version 0.00_20
+version 0.00_21
 
 =head1 SYNOPSIS
 
@@ -444,7 +431,7 @@ no arguments. return dipole calculated from charges and coordinates as Math::Vec
 
 no arguments. return center of mass calculated from masses and coordinates as Math::Vector::Real object  
 
-=head2 COM
+=head2 COZ
 
 no arguments. return center of nuclear charge calculated from Zs and coordinates as Math::Vector::Real object  
 
@@ -528,7 +515,11 @@ argument: Str , return hash_ref of binned $self->Str.
 
   $hash_ref{$_}++ foreach ( map {$_->$Str} $self->all_atoms );
 
-method fix_serial
+=head2 what_time
+
+returns the current setting of t by checking against all members of group.
+
+=head2 fix_serial
 
 argument, optional: Int, offset for resetting the serial number of atoms.  
 Returns the offset. 
